window.Gleam.initSearch([{"doc":"lustre_websocket","title":"lustre_websocket","content":"# lustre_websocket\n\n[![Package Version](https://img.shields.io/hexpm/v/lustre_websocket)](https://hex.pm/packages/lustre_websocket)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/lustre_websocket/)\n\nUse websockets from your `lustre` application!\n\n## Quick start\n\nAdd to your Gleam project:\n\n```sh\ngleam add lustre_websocket\n```\n\nTypical usage looks like\n```\nimport lustre_websocket as ws\n\npub type Msg {\n  WsWrapper(ws.WebSocketEvent)\n}\n\nfn init {\n  #(Model(None), ws.init(&quot;/path&quot;, WsWrapper))\n}\n```\nand then you pass `init` as first argument to `lustre.application`.\nBut you can create a socket at any time, esp. re-create it after it is closed by the server.\n\nThe events can be handled like this:\n```\nupdate(model, msg) {\n  case msg {\n    WsWrapper(OnOpen(socket)) -&gt; #(Model(..model, ws: Some(socket)), ws.send(socket, &quot;client-init&quot;))\n    WsWrapper(OnMessage(msg)) -&gt; todo\n    WsWrapper(OnClose(reason)) -&gt; #(Model(..model, ws: None), effect.none())\n  }\n}\n```\nwhich also demonstrates how you send a text message over the socket.\n\n### Caveat\n\n*This package cannot handle more than 1 socket on a server endpoint*\n\n### TODO:\n * support protocol choice, including one websocket per protocol per endpoint\n * support binary data\n * allow client to close the socket\n * provide errors to the application, when I have a clue on what those might actually be\n * prevent sending over closed sockets\n * maybe auto-reopen sockets that were closed because of Normal\n","url":"index.html"},{"doc":"lustre_websocket","title":"WebSocket","content":"pub type WebSocket\n\n\nSynonyms:\nlustre_websocket.WebSocket\nlustre_websocket WebSocket","url":"lustre_websocket.html#WebSocket"},{"doc":"lustre_websocket","title":"WebSocketCloseReason","content":"pub type WebSocketCloseReason {\n  Normal\n  GoingAway\n  ProtocolError\n  UnexpectedTypeOfData\n  NoCodeFromServer\n  AbnormalClose\n  IncomprehensibleFrame\n  PolicyViolated\n  MessageTooBig\n  FailedExtensionNegotation\n  UnexpectedFailure\n  FailedTLSHandshake\n  OtherCloseReason\n}\n\nNormal\n\n\nGoingAway\n\n\nProtocolError\n\n\nUnexpectedTypeOfData\n\n\nNoCodeFromServer\n\n\nAbnormalClose\n\n\nIncomprehensibleFrame\n\n\nPolicyViolated\n\n\nMessageTooBig\n\n\nFailedExtensionNegotation\n\n\nUnexpectedFailure\n\n\nFailedTLSHandshake\n\n\nOtherCloseReason\n\n\nSynonyms:\nlustre_websocket.WebSocketCloseReason\nlustre_websocket WebSocketCloseReason","url":"lustre_websocket.html#WebSocketCloseReason"},{"doc":"lustre_websocket","title":"WebSocketEvent","content":"pub type WebSocketEvent {\n  OnOpen(WebSocket)\n  OnMessage(String)\n  OnClose(WebSocketCloseReason)\n}\n\nOnOpen(WebSocket)\n\n\nOnMessage(String)\n\n\nOnClose(WebSocketCloseReason)\n\n\nSynonyms:\nlustre_websocket.WebSocketEvent\nlustre_websocket WebSocketEvent","url":"lustre_websocket.html#WebSocketEvent"},{"doc":"lustre_websocket","title":"close","content":"pub fn close(ws ws: WebSocket) -&gt; Effect(a)\n\nSynonyms:\nlustre_websocket.close\nlustre_websocket close","url":"lustre_websocket.html#close"},{"doc":"lustre_websocket","title":"init","content":"pub fn init(\n  path: String,\n  wrapper: fn(WebSocketEvent) -&gt; a,\n) -&gt; Effect(a)\n Initialize a websocket. These constructs are fully asynchronous, so you must provide a wrapper\n that takes a `WebSocketEvent` and turns it into a lustre message of your application.\nSynonyms:\nlustre_websocket.init\nlustre_websocket init","url":"lustre_websocket.html#init"},{"doc":"lustre_websocket","title":"send","content":"pub fn send(ws: WebSocket, msg: String) -&gt; Effect(a)\n Send a text message over the web socket. This is asynchronous. There is no\n expectation of a reply. See `init`. Only works on an Non-Closed socket.\n Returns a `Effect(a)` that you must pass as second entry in the lustre `update` return.\nSynonyms:\nlustre_websocket.send\nlustre_websocket send","url":"lustre_websocket.html#send"},{"doc":"lustre_websocket","title":"lustre_websocket","content":"","url":"lustre_websocket.html"}]);